@@ -197,7 +197,6 @@ try:
                 toconfirm_type.objects.get(id=object_id).is_active = True
                 break
 
-
     class AbstractConfirmfollowUser(models.Model):
         likes = models.ManyToManyField('self', related_name='liked', symmetrical=False)
         follows = models.ManyToManyField('self', through='FollowsConfirmed', symmetrical=False)
@@ -206,7 +205,6 @@ try:
             swappable = 'AUTH_USER_MODEL'
             abstract = True
 
-
     class FollowsConfirmed(models.Model):
         """
         Used as a though relation form followconfirmed models
@@ -226,16 +224,18 @@ try:
         def save(self, askconfirm=True, *args, **kwargs):
             super(FollowsConfirmed, self).save(*args, **kwargs)
             if not self.id:
-                if askconfirm:
-                    generate_and_send(self,
-                            request_template='altuser/mail_follow_request.html',
-                            success_template='altuser/mail_follows_confirmation_success.html',
-                            subject=_('Follow request'),
-                            to=self.followed.email,
-                    )
-                else:
-                    generate_confirmation(self, confirmed=True)
+                self.gen_confirmation(askconfirm)
 
+        def gen_confirmation(self, askconfirm):
+            if askconfirm:
+                generate_and_send(self,
+                                  request_template='altuser/mail_follow_request.html',
+                                  success_template='altuser/mail_follows_confirmation_success.html',
+                                  subject=_('Follow request'),
+                                  to=self.followed.email,
+                )
+            else:
+                generate_confirmation(self, confirmed=True)
 
     class MailSocialConfirmfollowUser(AbstractMailUser, AbstractConfirmfollowUser):
         """
